@@ -1,4 +1,5 @@
 from xml.etree import ElementTree
+import zipfile
 
 
 class DmxAddress:
@@ -66,7 +67,10 @@ class Matrix:
 class FixtureType:
 
     def __init__(self, path):
-        self._root = ElementTree.parse(path).getroot().find('FixtureType')
+        self._package = zipfile.ZipFile(path, 'r')
+        with self._package.open('description.xml', 'r') as f:
+            description_str = f.read()
+        self._root = ElementTree.fromstring(description_str).find('FixtureType')
         self.name = self._root.get('Name')
         self.short_name = self._root.get('ShortName')
         self.long_name = self._root.get('LongName')
@@ -327,7 +331,10 @@ class DmxChannel:
 
     def __init__(self, XDMXChannel):
         self.dmx_break = int(XDMXChannel.get('DMXBreak'))
-        self.offset = [int(i) for i in XDMXChannel.get('Offset').split(',')]
+        try:
+            self.offset = [int(i) for i in XDMXChannel.get('Offset').split(',')]
+        except ValueError:
+            self.offset = None
         self.default = DmxValue(XDMXChannel.get('Default', default='0/1'))
         self.highlight = DmxValue(XDMXChannel.get('Highlight'))
         self.geometry = XDMXChannel.get('Geometry')
